@@ -7,28 +7,21 @@ from .core.cache import APIResponsesCacheInvalidationStrategy, InMemoryCacheStor
 from .core.cache.storage import CacheStorage
 from .yoo_money import YooMoneyAPI
 
-try:
-    import uvloop
-
-    uvloop.install()  # pragma: no cover
-except ImportError:
-    pass
-
 
 def default_cache_storage() -> CacheStorage:
     return InMemoryCacheStorage(invalidate_strategy=APIResponsesCacheInvalidationStrategy())
 
 
-__version__ = "2.10"
+__version__ = '2.12'
 
 __all__ = (
     # clients
-    "YooMoneyAPI",
-    "QiwiMaps",
-    "QiwiWallet",
-    "QiwiP2PClient",
-    "QiwiWrapper",
+    'YooMoneyAPI',
+    'QiwiMaps',
+    'QiwiWallet',
+    'QiwiP2PClient',
+    'QiwiWrapper',
     # other
-    "__version__",
-    "default_cache_storage",
+    '__version__',
+    'default_cache_storage',
 )
