@@ -13,26 +13,26 @@ from .transaction import History, Source, Transaction, TransactionStatus, Transa
 from .webhooks import TransactionWebhook, WebhookInfo
 
 __all__ = (
-    "UserProfile",
-    "Transaction",
-    "Statistic",
-    "Limit",
-    "Balance",
-    "Identification",
-    "PaymentInfo",
-    "OrderDetails",
-    "Partner",
-    "TransactionWebhook",
-    "WebhookInfo",
-    "CrossRate",
-    "PaymentMethod",
-    "Card",
-    "Restriction",
-    "Commission",
-    "TransactionType",
-    "QiwiPayment",
-    "TransactionStatus",
-    "Source",
-    "PaymentDetails",
-    "History",
+    'UserProfile',
+    'Transaction',
+    'Statistic',
+    'Limit',
+    'Balance',
+    'Identification',
+    'PaymentInfo',
+    'OrderDetails',
+    'Partner',
+    'TransactionWebhook',
+    'WebhookInfo',
+    'CrossRate',
+    'PaymentMethod',
+    'Card',
+    'Restriction',
+    'Commission',
+    'TransactionType',
+    'QiwiPayment',
+    'TransactionStatus',
+    'Source',
+    'PaymentDetails',
+    'History',
 )
