@@ -15,9 +15,4 @@ class Base(BaseModel):
 class HashableBase(Base):
     class Config(BaseConfig):
         allow_mutation = False
-
-    def __hash__(self) -> int:
-        return hash((type(self),) + tuple(self.__dict__.values()))
-
-    def __eq__(self, other: Hashable) -> bool:
-        return self.__hash__() == other.__hash__()
+        frozen = True
