@@ -5,8 +5,8 @@ from glQiwiApi.yoo_money.types import Payment
 
 
 class ProcessPayment(APIMethod[Payment]):
-    http_method: ClassVar[str] = "POST"
-    url: ClassVar[str] = "https://yoomoney.ru/api/process-payment"
+    http_method: ClassVar[str] = 'POST'
+    url: ClassVar[str] = 'https://yoomoney.ru/api/process-payment'
 
     request_id: str
-    money_source: str = "wallet"
+    money_source: str = 'wallet'
